@@ -1,8 +1,6 @@
 /*
  * Remmina - The GTK Remote Desktop Client
- * Copyright (C) 2009-2010 Vic Lee
- * Copyright (C) 2014-2015 Antenore Gatta, Fabio Castelli, Giovanni Panozzo
- * Copyright (C) 2016-2020 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2014-2021 Antenore Gatta, Giovanni Panozzo
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,6 +47,10 @@
 #include "remmina_main.h"
 #include "remmina_masterthread_exec.h"
 #include "remmina_plugin_manager.h"
+#include "remmina_plugin_native.h"
+#ifdef WITH_PYTHONLIBS
+#include "remmina_plugin_python.h"
+#endif
 #include "remmina_pref.h"
 #include "remmina_public.h"
 #include "remmina_sftp_plugin.h"
@@ -80,39 +82,43 @@ gboolean kioskmode;
 
 static GOptionEntry remmina_options[] =
 {
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
 	{ "about",	      'a',  0,			  G_OPTION_ARG_NONE,	       NULL, N_("Show \'About\'"),								     NULL	},
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
-	{ "connect",	      'c',  0,			  G_OPTION_ARG_FILENAME,       NULL, N_("Connect to desktop described in file (.remmina or type supported by plugin)"),	     "FILE"	},
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
-	{ G_OPTION_REMAINING, '\0', 0,			  G_OPTION_ARG_FILENAME_ARRAY, NULL, N_("Connect to desktop described in file (.remmina or type supported by plugin)"),	     "FILE"	},
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
-	{ "edit",	      'e',  0,			  G_OPTION_ARG_FILENAME,       NULL, N_("Edit desktop connection described in file (.remmina or type supported by plugin)"), "FILE"	},
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
+	{ "connect",	      'c',  0,			  G_OPTION_ARG_FILENAME_ARRAY, NULL, N_("Connect either to a desktop described in a file (.remmina or a filetype supported by a plugin) or a supported URI (RDP, VNC, SSH or SPICE)"),	     N_("FILE")	},
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
+	{ G_OPTION_REMAINING, '\0', 0,			  G_OPTION_ARG_FILENAME_ARRAY, NULL, N_("Connect to a desktop described in a file (.remmina or a type supported by a plugin)"),	     N_("FILE")	},
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
+	{ "edit",	      'e',  0,			  G_OPTION_ARG_FILENAME_ARRAY, NULL, N_("Edit desktop connection described in file (.remmina or type supported by plugin)"), N_("FILE")	},
 	{ "help",	      '?',  G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE,	       NULL, NULL,										     NULL	},
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
-	{ "kiosk",	      'k',  0,			  G_OPTION_ARG_NONE,	       NULL, N_("Start in kiosk mode"),							     NULL	},
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
+	{ "kiosk",	      'k',  0,			  G_OPTION_ARG_NONE,	       NULL, N_("Start in kiosk mode"),								     NULL	},
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
 	{ "new",	      'n',  0,			  G_OPTION_ARG_NONE,	       NULL, N_("Create new connection profile"),						     NULL	},
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
-	{ "pref",	      'p',  0,			  G_OPTION_ARG_STRING,	       NULL, N_("Show preferences"),						     "PAGENR"	},
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
-	{ "plugin",	      'x',  0,			  G_OPTION_ARG_STRING,	       NULL, N_("Run a plugin"),								     "PLUGIN"	},
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
-	{ "quit",	      'q',  0,			  G_OPTION_ARG_NONE,	       NULL, N_("Quit"),							     NULL	},
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
-	{ "server",	      's',  0,			  G_OPTION_ARG_STRING,	       NULL, N_("Use default server name (for --new)"),						     "SERVER"	},
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
-	{ "protocol",	      't',  0,			  G_OPTION_ARG_STRING,	       NULL, N_("Use default protocol (for --new)"),						     "PROTOCOL" },
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
+	{ "pref",	      'p',  0,			  G_OPTION_ARG_STRING,	       NULL, N_("Show preferences"),								     N_("TABINDEX")	},
+#if 0
+	/* This option was used mainly for telepathy, let's keep it if we will need it in the future */
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
+	//{ "plugin",	      'x',  0,			  G_OPTION_ARG_STRING,	       NULL, N_("Run a plugin"),								     N_("PLUGIN")	},
+#endif
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
+	{ "quit",	      'q',  0,			  G_OPTION_ARG_NONE,	       NULL, N_("Quit"),									     NULL	},
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
+	{ "server",	      's',  0,			  G_OPTION_ARG_STRING,	       NULL, N_("Use default server name (for --new)"),						     N_("SERVER")	},
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
+	{ "protocol",	      't',  0,			  G_OPTION_ARG_STRING,	       NULL, N_("Use default protocol (for --new)"),						     N_("PROTOCOL") },
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
 	{ "icon",	      'i',  0,			  G_OPTION_ARG_NONE,	       NULL, N_("Start in tray"),								     NULL	},
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
 	{ "version",	      'v',  0,			  G_OPTION_ARG_NONE,	       NULL, N_("Show the application version"),						     NULL	},
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
-	{ "full-version",     'V',  0,			  G_OPTION_ARG_NONE,	       NULL, N_("Show version of the application and its plugins"),		     NULL	},
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
-	{ "update-profile",   0,    0,			  G_OPTION_ARG_FILENAME,       NULL, N_("Modify connection profile (requires --set-option)"),			     NULL	},
-	// TRANSLATORS: Shown in terminal. Do not use charcters that may be not supported on a terminal
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
+	{ "full-version",     'V',  0,			  G_OPTION_ARG_NONE,	       NULL, N_("Show version of the application and its plugins"),				     NULL	},
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
+	{ "update-profile",   0,    0,			  G_OPTION_ARG_FILENAME,       NULL, N_("Modify connection profile (requires --set-option)"),				     NULL	},
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
 	{ "set-option",	      0,    0,			  G_OPTION_ARG_STRING_ARRAY,   NULL, N_("Set one or more profile settings, to be used with --update-profile"),		     NULL	},
+	{ "encrypt-password", 0,    0,			  G_OPTION_ARG_NONE,	       NULL, N_("Encrypt a password"),												  NULL		 },
 	{ NULL }
 };
 
@@ -136,6 +142,7 @@ static gint remmina_on_command_line(GApplication *app, GApplicationCommandLine *
 	gboolean executed = FALSE;
 	GVariantDict *opts;
 	gchar *str;
+	const gchar **files;
 	const gchar **remaining_args;
 	gchar *protocol;
 	gchar *server;
@@ -158,13 +165,15 @@ static gint remmina_on_command_line(GApplication *app, GApplicationCommandLine *
 		executed = TRUE;
 	}
 
-	/** @todo This should be a G_OPTION_ARG_FILENAME_ARRAY (^aay) so that
-	 * we can implement multi profile connection:
-	 *    https://gitlab.com/Remmina/Remmina/issues/915
+	/** @warning To be used like -c FILE -c FILE -c FILE …
+	 *
 	 */
-	if (g_variant_dict_lookup(opts, "connect", "^ay", &str)) {
-		remmina_exec_command(REMMINA_COMMAND_CONNECT, g_strdup(str));
-		g_free(str);
+	if (g_variant_dict_lookup(opts, "connect", "^aay", &files)) {
+		if (files)
+			for (gint i = 0; files[i]; i++) {
+				g_debug ("Connecting to: %s", files[i]);
+				remmina_exec_command(REMMINA_COMMAND_CONNECT, files[i]);
+			}
 		executed = TRUE;
 	}
 
@@ -174,9 +183,14 @@ static gint remmina_on_command_line(GApplication *app, GApplicationCommandLine *
 		executed = TRUE;
 	}
 
-	if (g_variant_dict_lookup(opts, "edit", "^ay", &str)) {
-		remmina_exec_command(REMMINA_COMMAND_EDIT, str);
-		g_free(str);
+	if (g_variant_dict_lookup(opts, "edit", "^aay", &files)) {
+		if (files)
+			for (gint i = 0; files[i]; i++) {
+				g_debug ("Editing file: %s", files[i]);
+				remmina_exec_command(REMMINA_COMMAND_EDIT, files[i]);
+			}
+		//remmina_exec_command(REMMINA_COMMAND_EDIT, str);
+		//g_free(str);
 		executed = TRUE;
 	}
 
@@ -215,6 +229,12 @@ static gint remmina_on_command_line(GApplication *app, GApplicationCommandLine *
 		executed = TRUE;
 	}
 
+	if (g_variant_dict_lookup_value(opts, "encrypt-password", NULL)) {
+		remmina_exec_command(REMMINA_COMMAND_ENCRYPT_PASSWORD, NULL);
+		executed = TRUE;
+		status = 1;
+	}
+
 	if (!executed)
 		remmina_exec_command(REMMINA_COMMAND_MAIN, NULL);
 
@@ -249,12 +269,11 @@ static void remmina_on_startup(GApplication *app)
 	/* Check for secret plugin and service initialization and show console warnings if
 	 * something is missing */
 	secret_plugin = remmina_plugin_manager_get_secret_plugin();
-	if (!secret_plugin) {
+	if (!secret_plugin)
 		g_print("Warning: Remmina is running without a secret plugin. Passwords will be saved in a less secure way.\n");
-	} else {
+	else
 		if (!secret_plugin->is_service_available())
 			g_print("Warning: Remmina is running with a secrecy plugin, but it cannot connect to a secrecy service.\n");
-	}
 
 	remmina_exec_command(REMMINA_COMMAND_AUTOSTART, NULL);
 }
@@ -303,9 +322,10 @@ int main(int argc, char *argv[])
 	TRACE_CALL(__func__);
 	GtkApplication *app;
 	const gchar *app_id;
+	gchar *summary;
 	int status;
 
-	g_unsetenv ("GDK_CORE_DEVICE_EVENTS");
+	g_unsetenv("GDK_CORE_DEVICE_EVENTS");
 
 	/* Enable wayland backend only after GTK 3.22.27 or the clipboard
 	 * will not work. See GTK bug 790031 */
@@ -322,7 +342,7 @@ int main(int argc, char *argv[])
 
 #ifdef HAVE_LIBGCRYPT
 # if GCRYPT_VERSION_NUMBER < 0x010600
-    gcry_error_t e;
+	gcry_error_t e;
 	if (!gcrypt_thread_initialized) {
 		if ((e = gcry_control(GCRYCTL_SET_THREAD_CBS, &gcry_threads_pthread)) != GPG_ERR_NO_ERROR)
 			return -1;
@@ -337,19 +357,56 @@ int main(int argc, char *argv[])
 	/* Initialize some Remmina parts needed also on a local instance for correct handle-local-options */
 	remmina_pref_init();
 	remmina_file_manager_init();
+
 	remmina_plugin_manager_init();
 
 
+
 	app_id = g_application_id_is_valid(REMMINA_APP_ID) ? REMMINA_APP_ID : NULL;
-	app = gtk_application_new(app_id, G_APPLICATION_HANDLES_COMMAND_LINE);
+	app = gtk_application_new(app_id, G_APPLICATION_HANDLES_COMMAND_LINE | G_APPLICATION_CAN_OVERRIDE_APP_ID);
 #if !GTK_CHECK_VERSION(4, 0, 0) /* This is not needed anymore starting from GTK 4 */
 	g_set_prgname(app_id);
 #endif
+	g_application_add_main_option_entries(G_APPLICATION(app), remmina_options);
+	summary = g_strdup_printf ("%s %s", app_id, VERSION);
+	g_application_set_option_context_summary (G_APPLICATION(app), summary);
+	g_free(summary);
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
+	g_application_set_option_context_parameter_string (G_APPLICATION(app), _("- or protocol://username:encryptedpassword@host:port"));
+	// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
+	g_application_set_option_context_description (G_APPLICATION(app),
+			_("Examples:\n"
+				"To connect using an existing connection profile, use:\n"
+				"\n"
+				"\tremmina -c FILE.remmina\n"
+				"\n"
+				"To quick connect using a URI:\n"
+				"\n"
+				"\tremmina -c rdp://username@server\n"
+				"\tremmina -c rdp://domain\\\\username@server\n"
+				"\tremmina -c vnc://username@server\n"
+				"\tremmina -c vnc://server?VncUsername=username\n"
+				"\tremmina -c ssh://user@server\n"
+				"\tremmina -c spice://server\n"
+				"\n"
+				"To quick connect using a URI along with an encrypted password:\n"
+				"\n"
+				"\tremmina -c rdp://username:encrypted-password@server\n"
+				"\tremmina -c vnc://username:encrypted-password@server\n"
+				"\tremmina -c vnc://server?VncUsername=username\\&VncPassword=encrypted-password\n"
+				"\n"
+				"To encrypt a password for use with a URI:\n"
+				"\n"
+				"\tremmina --encrypt-password\n"
+				"\n"
+				"To update username and password and set a different resolution mode of a Remmina connection profile, use:\n"
+				"\n"
+				"\techo \"username\\napassword\" | remmina --update-profile /PATH/TO/FOO.remmina --set-option username --set-option resolution_mode=2 --set-option password\n"));
+
 	g_signal_connect(app, "startup", G_CALLBACK(remmina_on_startup), NULL);
 	g_signal_connect(app, "command-line", G_CALLBACK(remmina_on_command_line), NULL);
 	g_signal_connect(app, "handle-local-options", G_CALLBACK(remmina_on_local_cmdline), NULL);
 
-	g_application_add_main_option_entries(G_APPLICATION(app), remmina_options);
 
 	g_application_set_inactivity_timeout(G_APPLICATION(app), 10000);
 	status = g_application_run(G_APPLICATION(app), argc, argv);
