@@ -1,7 +1,7 @@
 /*
  * Remmina - The GTK+ Remote Desktop Client
  * Copyright (C) 2009-2010 Vic Lee
- * Copyright (C) 2014-2020 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2014-2021 Antenore Gatta, Giovanni Panozzo
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,8 +61,6 @@ static void wait_for_child(GPid pid, gint script_retval, gpointer data)
 	 * remmina connection.
 	 * Adding a delay here could be a (not good) solution, or we should
 	 * monitor each child opened, but it could be quit tricky and messy */
-
-	g_free(pcspinner);
 }
 
 GtkDialog* remmina_ext_exec_new(RemminaFile* remminafile, const char *remmina_ext_exec_type)
@@ -83,12 +81,13 @@ GtkDialog* remmina_ext_exec_new(RemminaFile* remminafile, const char *remmina_ex
 	if (remmina_ext_exec_type != NULL && (
 				strcmp(remmina_ext_exec_type, pre) |
 				strcmp(remmina_ext_exec_type, post) )) {
-		cmd = remmina_file_get_string(remminafile, remmina_ext_exec_type);
-	}else{
+		cmd = g_strdup(remmina_file_get_string(remminafile, remmina_ext_exec_type));
+		g_debug("[%s] %s", remmina_ext_exec_type, cmd);
+	} else
 		return FALSE;
-	}
 
 	cmd = remmina_file_format_properties(remminafile, cmd);
+	g_debug("[%s] updated to: %s", remmina_ext_exec_type, cmd);
 	if (*cmd != 0) {
 
 		pcspinner = g_new(PCon_Spinner, 1);
