@@ -2,7 +2,7 @@
  * Remmina - The GTK+ Remote Desktop Client
  * Copyright (C) 2009-2011 Vic Lee
  * Copyright (C) 2014-2015 Antenore Gatta, Fabio Castelli, Giovanni Panozzo
- * Copyright (C) 2016-2020 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2016-2021 Antenore Gatta, Giovanni Panozzo
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -342,7 +342,7 @@ static gboolean remmina_file_multipasswd_changer_mt(gpointer d)
 
 	bu = remmina_public_gtk_builder_new_from_file("remmina_mpc.glade");
 	if (!bu) {
-		REMMINA_DEBUG("Unable to load the multiple password changer glade file interface\n");
+		REMMINA_DEBUG("Unable to load the multiple password changer Glade file interface\n");
 		return FALSE;
 	}
 
