@@ -1,7 +1,7 @@
 /*
  * Remmina - The GTK+ Remote Desktop Client
  * Copyright (C) 2009-2011 Vic Lee
- * Copyright (C) 2017-2020 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2017-2021 Antenore Gatta, Giovanni Panozzo
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -58,12 +58,14 @@ typedef struct _RemminaPrefDialog {
 	GtkEntry *		unlock_timeout;
 	GtkEntry *		unlock_password;
 	GtkEntry *		unlock_repassword;
+	GtkSwitch *		switch_security_trust_all;
 	GtkCheckButton *	checkbutton_options_save_settings;
 	GtkCheckButton *	checkbutton_appearance_fullscreen_on_auto;
 	GtkCheckButton *	checkbutton_appearance_show_tabs;
 	GtkCheckButton *	checkbutton_appearance_hide_toolbar;
 	GtkCheckButton *	checkbutton_appearance_hide_searchbar;
 	GtkSwitch *		switch_permit_send_stats;
+	GtkSwitch *		switch_permit_news;
 	GtkComboBox *		comboboxtext_options_double_click;
 	GtkComboBox *		comboboxtext_appearance_view_mode;
 	GtkComboBox *		comboboxtext_appearance_tab_interface;
@@ -111,10 +113,15 @@ typedef struct _RemminaPrefDialog {
 	GtkButton *		button_keyboard_copy;
 	GtkButton *		button_keyboard_paste;
 	GtkButton *		button_keyboard_select_all;
+	GtkButton *		button_keyboard_increase_font;
+	GtkButton *		button_keyboard_decrease_font;
+	GtkButton *		button_keyboard_search_text;
 	GtkLabel *		label_terminal_cursor_color;
+	GtkLabel *		label_terminal_bold_color;
 	GtkLabel *		label_terminal_normal_colors;
 	GtkLabel *		label_terminal_bright_colors;
 	GtkColorButton *	colorbutton_cursor;
+	GtkColorButton *	colorbutton_bold;
 	GtkColorButton *	colorbutton_color0;
 	GtkColorButton *	colorbutton_color1;
 	GtkColorButton *	colorbutton_color2;
