@@ -2,7 +2,7 @@
  * Remmina - The GTK+ Remote Desktop Client
  * Copyright (C) 2009-2011 Vic Lee
  * Copyright (C) 2014-2015 Antenore Gatta, Fabio Castelli, Giovanni Panozzo
- * Copyright (C) 2016-2020 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2016-2021 Antenore Gatta, Giovanni Panozzo
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -67,6 +67,9 @@ remmina_public_create_combo_entry(const gchar *text, const gchar *def, gboolean
 	gchar *buf, *ptr1, *ptr2;
 	gint i;
 
+	g_print("text: %s\n", text);
+	g_print("def: %s\n", def);
+
 	combo = gtk_combo_box_text_new_with_entry();
 	found = FALSE;
 
@@ -333,47 +336,29 @@ remmina_public_combine_path(const gchar *path1, const gchar *path2)
 void remmina_public_get_server_port(const gchar *server, gint defaultport, gchar **host, gint *port)
 {
 	TRACE_CALL(__func__);
-	gchar *str, *ptr, *ptr2;
 
-	str = g_strdup(server);
+	const gchar *nul_terminated_server = NULL;
+	if (server != NULL) {
+		GNetworkAddress *address;
+		GError *err;
 
-	if (str) {
-		/* [server]:port format */
-		ptr = strchr(str, '[');
-		if (ptr) {
-			ptr++;
-			ptr2 = strchr(ptr, ']');
-			if (ptr2) {
-				*ptr2++ = '\0';
-				if (*ptr2 == ':')
-					defaultport = atoi(ptr2 + 1);
-			}
-			if (host)
-				*host = g_strdup(ptr);
-			if (port)
-				*port = defaultport;
-			g_free(str);
-			return;
+		nul_terminated_server = g_strdup (server);
+		g_debug ("(%s) - Parsing server: %s, default port: %d", __func__, server, defaultport);
+		address = (GNetworkAddress*)g_network_address_parse ((const gchar *) nul_terminated_server,  defaultport, &err);
+
+		if (address == NULL) {
+			g_debug ("(%s) - Error converting server string: %s, with error: %s", __func__, nul_terminated_server, err->message);
 		}
 
-		/* server:port format, IPv6 cannot use this format */
-		ptr = strchr(str, ':');
-		if (ptr) {
-			ptr2 = strchr(ptr + 1, ':');
-			if (ptr2 == NULL) {
-				*ptr++ = '\0';
-				defaultport = atoi(ptr);
-			}
-			/* More than one ':' means this is IPv6 address. Treat it as a whole address */
-		}
-	}
+		*host = g_strdup(g_network_address_get_hostname (address));
+		*port = g_network_address_get_port (address);
+	} else
+		*host = NULL;
 
-	if (host)
-		*host = str;
-	else
-		g_free(str);
-	if (port)
+	if (port == 0)
 		*port = defaultport;
+
+	return;
 }
 
 gboolean remmina_public_get_xauth_cookie(const gchar *display, gchar **msg)
