@@ -2,7 +2,7 @@
  * Remmina - The GTK+ Remote Desktop Client
  * Copyright (C) 2009-2010 Vic Lee
  * Copyright (C) 2014-2015 Antenore Gatta, Fabio Castelli, Giovanni Panozzo
- * Copyright (C) 2016-2020 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2016-2021 Antenore Gatta, Giovanni Panozzo
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -170,15 +170,15 @@ remmina_sftp_client_thread_download_file(RemminaSFTPClient *client, RemminaSFTP
 		*tmp = '\0';
 		if (g_mkdir_with_parents(buf, 0755) < 0) {
 			// TRANSLATORS: The placeholder %s is a directory path
-			remmina_sftp_client_thread_set_error(client, task, _("Could not create the folder \"%s\"."), buf);
+			remmina_sftp_client_thread_set_error(client, task, _("Could not create the folder “%s”."), buf);
 			return FALSE;
 		}
 	}
 
 	local_file = g_fopen(local_path, "ab");
 	if (!local_file) {
-			// TRANSLATORS: The placeholder %s is a file path
-		remmina_sftp_client_thread_set_error(client, task, _("Could not create the file \"%s\"."), local_path);
+		// TRANSLATORS: The placeholder %s is a file path
+		remmina_sftp_client_thread_set_error(client, task, _("Could not create the file “%s”."), local_path);
 		return FALSE;
 	}
 
@@ -199,7 +199,7 @@ remmina_sftp_client_thread_download_file(RemminaSFTPClient *client, RemminaSFTP
 			local_file = g_fopen(local_path, "wb");
 			if (!local_file) {
 				// TRANSLATORS: The placeholder %s is a file path
-				remmina_sftp_client_thread_set_error(client, task, _("Could not create the file \"%s\"."), local_path);
+				remmina_sftp_client_thread_set_error(client, task, _("Could not create the file “%s”."), local_path);
 				return FALSE;
 			}
 			size = 0;
@@ -217,7 +217,7 @@ remmina_sftp_client_thread_download_file(RemminaSFTPClient *client, RemminaSFTP
 	if (!remote_file) {
 		fclose(local_file);
 		// TRANSLATORS: The placeholders %s are a file path, and an error message.
-		remmina_sftp_client_thread_set_error(client, task, _("Could not open the file \"%s\" on the server. %s"),
+		remmina_sftp_client_thread_set_error(client, task, _("Could not open the file “%s” on the server. %s"),
 						     remote_path, ssh_get_error(REMMINA_SSH(client->sftp)->session));
 		return FALSE;
 	}
@@ -226,7 +226,7 @@ remmina_sftp_client_thread_download_file(RemminaSFTPClient *client, RemminaSFTP
 		if (sftp_seek64(remote_file, size) < 0) {
 			sftp_close(remote_file);
 			fclose(local_file);
-			remmina_sftp_client_thread_set_error(client, task, "Could not download the file \"%s\". %s",
+			remmina_sftp_client_thread_set_error(client, task, "Could not download the file “%s”. %s",
 							     remote_path, ssh_get_error(REMMINA_SSH(client->sftp)->session));
 			return FALSE;
 		}
@@ -239,7 +239,7 @@ remmina_sftp_client_thread_download_file(RemminaSFTPClient *client, RemminaSFTP
 		if (fwrite(buf, 1, len, local_file) < len) {
 			sftp_close(remote_file);
 			fclose(local_file);
-			remmina_sftp_client_thread_set_error(client, task, _("Could not save the file \"%s\"."), local_path);
+			remmina_sftp_client_thread_set_error(client, task, _("Could not save the file “%s”."), local_path);
 			return FALSE;
 		}
 
@@ -278,7 +278,7 @@ remmina_sftp_client_thread_recursive_dir(RemminaSFTPClient *client, RemminaSFTP
 	g_free(tmp);
 
 	if (!sftpdir) {
-		remmina_sftp_client_thread_set_error(client, task, _("Could not open the folder \"%s\". %s"),
+		remmina_sftp_client_thread_set_error(client, task, _("Could not open the folder “%s”. %s"),
 						     dir_path, ssh_get_error(REMMINA_SSH(client->sftp)->session));
 		g_free(dir_path);
 		return FALSE;
@@ -382,7 +382,7 @@ remmina_sftp_client_thread_mkdir(RemminaSFTPClient *client, RemminaSFTP *sftp, R
 		return TRUE;
 	}
 	if (sftp_mkdir(sftp->sftp_sess, path, 0755) < 0) {
-		remmina_sftp_client_thread_set_error(client, task, _("Could not create the folder \"%s\" on the server. %s"),
+		remmina_sftp_client_thread_set_error(client, task, _("Could not create the folder “%s” on the server. %s"),
 						     path, ssh_get_error(REMMINA_SSH(client->sftp)->session));
 		return FALSE;
 	}
@@ -410,7 +410,7 @@ remmina_sftp_client_thread_upload_file(RemminaSFTPClient *client, RemminaSFTP *s
 	g_free(tmp);
 
 	if (!remote_file) {
-		remmina_sftp_client_thread_set_error(client, task, _("Could not create the file \"%s\" on the server. %s"),
+		remmina_sftp_client_thread_set_error(client, task, _("Could not create the file “%s” on the server. %s"),
 						     remote_path, ssh_get_error(REMMINA_SSH(client->sftp)->session));
 		return FALSE;
 	}
@@ -432,7 +432,7 @@ remmina_sftp_client_thread_upload_file(RemminaSFTPClient *client, RemminaSFTP *s
 			remote_file = sftp_open(sftp->sftp_sess, tmp, O_WRONLY | O_CREAT | O_TRUNC, 0644);
 			g_free(tmp);
 			if (!remote_file) {
-				remmina_sftp_client_thread_set_error(client, task, _("Could not create the file \"%s\" on the server. %s"),
+				remmina_sftp_client_thread_set_error(client, task, _("Could not create the file “%s” on the server. %s"),
 								     remote_path, ssh_get_error(REMMINA_SSH(client->sftp)->session));
 				return FALSE;
 			}
@@ -442,7 +442,7 @@ remmina_sftp_client_thread_upload_file(RemminaSFTPClient *client, RemminaSFTP *s
 		case GTK_RESPONSE_APPLY:
 			if (sftp_seek64(remote_file, size) < 0) {
 				sftp_close(remote_file);
-				remmina_sftp_client_thread_set_error(client, task, "Could not download the file \"%s\". %s",
+				remmina_sftp_client_thread_set_error(client, task, "Could not download the file “%s”. %s",
 								     remote_path, ssh_get_error(REMMINA_SSH(client->sftp)->session));
 				return FALSE;
 			}
@@ -453,7 +453,7 @@ remmina_sftp_client_thread_upload_file(RemminaSFTPClient *client, RemminaSFTP *s
 	local_file = g_fopen(local_path, "rb");
 	if (!local_file) {
 		sftp_close(remote_file);
-		remmina_sftp_client_thread_set_error(client, task, _("Could not open the file \"%s\"."), local_path);
+		remmina_sftp_client_thread_set_error(client, task, _("Could not open the file “%s”."), local_path);
 		return FALSE;
 	}
 
@@ -461,7 +461,7 @@ remmina_sftp_client_thread_upload_file(RemminaSFTPClient *client, RemminaSFTP *s
 		if (fseeko(local_file, size, SEEK_SET) < 0) {
 			sftp_close(remote_file);
 			fclose(local_file);
-			remmina_sftp_client_thread_set_error(client, task, "Could not find the local file \"%s\".", local_path);
+			remmina_sftp_client_thread_set_error(client, task, "Could not find the local file “%s”.", local_path);
 			return FALSE;
 		}
 		*donesize = size;
@@ -473,7 +473,7 @@ remmina_sftp_client_thread_upload_file(RemminaSFTPClient *client, RemminaSFTP *s
 		if (sftp_write(remote_file, buf, len) < len) {
 			sftp_close(remote_file);
 			fclose(local_file);
-			remmina_sftp_client_thread_set_error(client, task, _("Could not write to the file \"%s\" on the server. %s"),
+			remmina_sftp_client_thread_set_error(client, task, _("Could not write to the file “%s” on the server. %s"),
 							     remote_path, ssh_get_error(REMMINA_SSH(client->sftp)->session));
 			return FALSE;
 		}
@@ -695,7 +695,7 @@ remmina_sftp_client_sftp_session_opendir(RemminaSFTPClient *client, const gchar
 	if (!sftpdir) {
 		dialog = gtk_message_dialog_new(GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(client))),
 						GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-						_("Could not open the folder \"%s\". %s"), dir,
+						_("Could not open the folder “%s”. %s"), dir,
 						ssh_get_error(REMMINA_SSH(client->sftp)->session));
 		gtk_dialog_run(GTK_DIALOG(dialog));
 		gtk_widget_destroy(dialog);
@@ -758,7 +758,7 @@ remmina_sftp_client_on_opendir(RemminaSFTPClient *client, gchar *dir, gpointer d
 	if (!newdir) {
 		dialog = gtk_message_dialog_new(NULL,
 						GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-						_("Could not open the folder \"%s\". %s"), dir,
+						_("Could not open the folder “%s”. %s"), dir,
 						ssh_get_error(REMMINA_SSH(client->sftp)->session));
 		gtk_widget_show(dialog);
 		g_signal_connect(G_OBJECT(dialog), "response", G_CALLBACK(gtk_widget_destroy), NULL);
@@ -854,7 +854,7 @@ remmina_sftp_client_on_deletefile(RemminaSFTPClient *client, gint type, gchar *n
 	if (ret != 0) {
 		dialog = gtk_message_dialog_new(GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(client))),
 						GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-						_("Could not delete \"%s\". %s"),
+						_("Could not delete “%s”. %s"),
 						name, ssh_get_error(REMMINA_SSH(client->sftp)->session));
 		gtk_dialog_run(GTK_DIALOG(dialog));
 		gtk_widget_destroy(dialog);
@@ -918,6 +918,10 @@ remmina_sftp_client_confirm_resume(RemminaSFTPClient *client, const gchar *path)
 	if (remmina_ftp_client_get_overwrite_status(REMMINA_FTP_CLIENT(client)))
 		return GTK_RESPONSE_ACCEPT;
 
+	/* Always reply APPLY if resume was already set */
+	if (remmina_ftp_client_get_resume_status(REMMINA_FTP_CLIENT(client)))
+		return GTK_RESPONSE_APPLY;
+
 	if (!remmina_masterthread_exec_is_main_thread()) {
 		/* Allow the execution of this function from a non main thread */
 		RemminaMTExecData *d;
@@ -949,7 +953,7 @@ remmina_sftp_client_confirm_resume(RemminaSFTPClient *client, const gchar *path)
 	gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
 			   hbox, TRUE, TRUE, 4);
 
-	widget = gtk_image_new_from_icon_name(_("Question"), GTK_ICON_SIZE_DIALOG);
+	widget = gtk_image_new_from_icon_name("dialog-question", GTK_ICON_SIZE_DIALOG);
 	gtk_widget_show(widget);
 	gtk_box_pack_start(GTK_BOX(hbox), widget, TRUE, TRUE, 4);
 
@@ -991,38 +995,38 @@ remmina_sftp_client_open(RemminaSFTPClient *client, RemminaSFTP *sftp)
 }
 
 /*
-GtkWidget *
-remmina_sftp_client_new_init(RemminaSFTP *sftp)
-{
-	TRACE_CALL(__func__);
-	GdkDisplay *display;
-	GtkWidget *client;
-	GtkWidget *dialog;
-
-	display = gdk_display_get_default();
-	client = remmina_sftp_client_new();
-
-
-	SET_CURSOR(gdk_cursor_new_for_display(display, GDK_WATCH));
-	gdk_display_flush(display);
-
-	if (!remmina_ssh_init_session(REMMINA_SSH(sftp)) ||
-	    remmina_ssh_auth(REMMINA_SSH(sftp), NULL, NULL, NULL) != REMMINA_SSH_AUTH_SUCCESS ||
-	    !remmina_sftp_open(sftp)) {
-		dialog = gtk_message_dialog_new(GTK_WINDOW(gtk_widget_get_toplevel(client)),
-						GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-						(REMMINA_SSH(sftp))->error, NULL);
-		gtk_dialog_run(GTK_DIALOG(dialog));
-		gtk_widget_destroy(dialog);
-		gtk_widget_destroy(client);
-		return NULL;
-	}
-
-	SET_CURSOR(NULL);
-
-	g_idle_add((GSourceFunc)remmina_sftp_client_refresh, client);
-	return client;
-}
-*/
+ * GtkWidget *
+ * remmina_sftp_client_new_init(RemminaSFTP *sftp)
+ * {
+ *      TRACE_CALL(__func__);
+ *      GdkDisplay *display;
+ *      GtkWidget *client;
+ *      GtkWidget *dialog;
+ *
+ *      display = gdk_display_get_default();
+ *      client = remmina_sftp_client_new();
+ *
+ *
+ *      SET_CURSOR(gdk_cursor_new_for_display(display, GDK_WATCH));
+ *      gdk_display_flush(display);
+ *
+ *      if (!remmina_ssh_init_session(REMMINA_SSH(sftp)) ||
+ *          remmina_ssh_auth(REMMINA_SSH(sftp), NULL, NULL, NULL) != REMMINA_SSH_AUTH_SUCCESS ||
+ *          !remmina_sftp_open(sftp)) {
+ *              dialog = gtk_message_dialog_new(GTK_WINDOW(gtk_widget_get_toplevel(client)),
+ *                                              GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+ *                                              (REMMINA_SSH(sftp))->error, NULL);
+ *              gtk_dialog_run(GTK_DIALOG(dialog));
+ *              gtk_widget_destroy(dialog);
+ *              gtk_widget_destroy(client);
+ *              return NULL;
+ *      }
+ *
+ *      SET_CURSOR(NULL);
+ *
+ *      g_idle_add((GSourceFunc)remmina_sftp_client_refresh, client);
+ *      return client;
+ * }
+ */
 
 #endif
