@@ -1,6 +1,6 @@
 /*
  * Remmina - The GTK+ Remote Desktop Client
- * Copyright (C) 2016-2020 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2016-2021 Antenore Gatta, Giovanni Panozzo
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,6 +53,7 @@
 #include "remmina_log.h"
 #include "remmina_pref.h"
 #include "remmina_public.h"
+#include "remmina_sodium.h"
 #include "remmina_utils.h"
 #include "remmina_scheduler.h"
 #include "remmina_stats_sender.h"
@@ -522,21 +523,19 @@ static gboolean rmnews_periodic_check(gpointer user_data)
 	gint64 unixts;
 	glong next = 0;
 
-	srand(time(NULL));
-
 	gdt = g_date_time_new_now_utc();
 	unixts = g_date_time_to_unix(gdt);
 	g_date_time_unref(gdt);
 
 	/* if remmina_pref is not writable ... */
 	if (remmina_pref_is_rw() == FALSE && remmina_pref.periodic_rmnews_last_get == 0) {
-		gint randidx = rand() % 7;
 		/* We randmoly set periodic_rmnews_last_get to a a day between today
 		 * and 7 days ago */
-		REMMINA_DEBUG("Setting a random periodic_rmnews_last_get");
+		gint randidx = randombytes_uniform(8);
+		REMMINA_DEBUG("Setting a random periodic_rmnews_last_get to %d - %d", unixts, eweekdays[randidx]);
 		remmina_pref.periodic_rmnews_last_get = unixts - eweekdays[randidx];
 	}
-	REMMINA_DEBUG("periodic_rmnews_last_get is %ld", remmina_pref.periodic_rmnews_last_get);
+	//REMMINA_DEBUG("periodic_rmnews_last_get is %ld", remmina_pref.periodic_rmnews_last_get);
 
 	if (remmina_pref.periodic_news_permitted == 0 && remmina_pref.periodic_rmnews_get_count < 1) {
 		remmina_pref.periodic_rmnews_last_get =
